minor : fix typo in comment

Change-Id: Ie310143fe713a51fa1adf8bf7599374282341f2e
diff --git a/firmware/libcommon/source/simtrace_iso7816.c b/firmware/libcommon/source/simtrace_iso7816.c
index 889ca2d..8ee3f8c 100644
--- a/firmware/libcommon/source/simtrace_iso7816.c
+++ b/firmware/libcommon/source/simtrace_iso7816.c
@@ -80,7 +80,7 @@
 }
 
 /*
  *  char_stat is zero if no error occured.
  *  Otherwise it is filled with the content of the status register.
  */
 void mode_trace_usart1_irq(void)
@@ -110,7 +110,7 @@
 			rbuf_write(&sim_rcv_buf, c);
 		} else {
 			TRACE_DEBUG("e %x st: %x\n", c, stat);
-		}		/* else: error occured */
+		}		/* else: error occurred */
 
 		char_stat = stat;
 	}
@@ -80,7 +80,7 @@
 
 /*
- *  char_stat is zero if no error occured.
+ *  char_stat is zero if no error occurred.
  *  Otherwise it is filled with the content of the status register.
  */